from distutils.core import setup

setup(
		name	= 'lumia',
		version	= '1.2.1',
		py_modules = ['nester'],
		author = 'lumia',
		author_email = 'lumiahuan@gmail.com',
		url	= 'https://twitter.com/LCanaryM',
		description = 'A simple printer of nested listed',
	)